import { program, Command } from '@/program.ts';
import inquirer from 'inquirer';
import { query } from '../module/index.ts';
import chalk from 'chalk';
import util from 'util';
import { runApp } from '@/app-run.ts';

const router = new Command('router').description('router get');
program.addCommand(router);
// web 开发模块
const command = new Command('service')
  .description('router services get')
  .option('-p, --path <path>', '第一路径 path')
  .option('-k, --key <key>', '第二路径 key')
  .action(async (options) => {
    let { path, key } = options;
    // 如果没有传递参数，则通过交互式输入
    if (!path) {
      const answers = await inquirer.prompt([
        {
          type: 'input',
          name: 'path',
          required: true,
          message: 'Enter your path:',
          when: () => !path, // 当 username 为空时，提示用户输入
        },
      ]);
      path = answers.path || path;
    }
    if (!key) {
      const answers = await inquirer.prompt([
        {
          type: 'input',
          required: false,
          name: 'key',
          message: 'Enter your key:',
        },
      ]);
      key = answers.key || key;
    }
    const res = await query.post({ path, key });
    if (res?.code === 200) {
      console.log('query success');
      const _list = res.data?.list || res.data;
      if (Array.isArray(_list)) {
        const data = _list.map((item: any) => {
          // return `id: ${item.id}, title: ${item.title}`;
          return {
            id: item.id,
            title: item.title,
          };
        });
        console.log(chalk.green(util.inspect(data, { colors: true, depth: 4 })));
      }
    } else {
      console.log('error', res.message || '');
    }
  });

router.addCommand(command);

const localRouter = new Command('local')
  .description('router local get')
  .option('-p, --path <path>', '第一路径 path')
  .option('-k, --key <key>', '第二路径 key')
  .action(async (options) => {
    let { path, key } = options;
    // 如果没有传递参数，则通过交互式输入
    if (!path) {
      const answers = await inquirer.prompt([
        {
          type: 'input',
          name: 'path',
          required: true,
          message: 'Enter your path:',
          when: () => !path, // 当 username 为空时，提示用户输入
        },
      ]);
      path = answers.path || path;
    }
    if (!key) {
      const answers = await inquirer.prompt([
        {
          type: 'input',
          required: false,
          name: 'key',
          message: 'Enter your key:',
        },
      ]);
      key = answers.key || key;
    }
    const res = await runApp({ path, key });
    if (res?.code === 200) {
      console.log('query success');

      console.log(chalk.green(util.inspect(res, { colors: true, depth: 4 })));
    } else {
      console.log('error query', res.code, res.message || '');
    }
  });

router.addCommand(localRouter);
